#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-cors
version:              0.2.7
visibility:           public
id:                   wai-cors-0.2.7-DepLhfPh3hjCzFTL7eCI8S
key:                  wai-cors-0.2.7-DepLhfPh3hjCzFTL7eCI8S
license:              MIT
copyright:
    (c) 2015-2019 Lars Kuhtz <lakuhtz@gmail.com>,
    (c) 2014 AlephCloud Systems, Inc.

maintainer:           Lars Kuhtz <lakuhtz@gmail.com>
author:               Lars Kuhtz <lakuhtz@gmail.com>
homepage:             https://github.com/larskuhtz/wai-cors
synopsis:             CORS for WAI
description:
    This package provides an implemenation of
    Cross-Origin resource sharing (CORS) for
    <http://hackage.haskell.org/package/wai Wai>
    that aims to be compliant with <http://www.w3.org/TR/cors>.

category:             HTTP, Network, Web, Wai
abi:                  8902acc6888dad2b39f571ef95a9ec37
exposed:              True
exposed-modules:      Network.Wai.Middleware.Cors
import-dirs:          /usr/lib/ghc-8.10.5/site-local/wai-cors-0.2.7
library-dirs:         /usr/lib/ghc-8.10.5/site-local/wai-cors-0.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/wai-cors-0.2.7
hs-libraries:         HSwai-cors-0.2.7-DepLhfPh3hjCzFTL7eCI8S
depends:
    attoparsec-0.14.1-CDW2c9fsk3y4jVQKNBcpib base-4.14.2.0
    base-unicode-symbols-0.2.4.2-91RZnOG3rhvDK4lQIU0nQT
    bytestring-0.10.12.0
    case-insensitive-1.2.1.0-G5jOpOHgp1lAnadtJPMHHB
    http-types-0.12.3-JSCBEGU6f6MIPS3hXwEPIB mtl-2.2.2
    transformers-0.5.6.2 wai-3.2.3-6NrdunSiuKK6vnccK2cwty

haddock-interfaces:   /usr/share/doc/haskell-wai-cors/html/wai-cors.haddock
haddock-html:         /usr/share/doc/haskell-wai-cors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

